anime_target_id: Target SVG or HTML elements by a data-animejs-id attribute

View source: R/targets.R

anime_target_idR Documentation

Target SVG or HTML elements by a data-animejs-id attribute

Description

The primary mechanism for targeting individual elements annotated with a data-animejs-id attribute, by hand or by an upstream SVG annotation tool.

Usage

anime_target_id(id)

Arguments

id

Character scalar. Value of the data-animejs-id attribute.

Value

A CSS selector string of the form "[data-animejs-id='<id>']".

Examples

anime_target_id("c1")


animejs documentation built on Aug. 21, 2026, 5:17 p.m.