The primary mechanism for targeting individual elements annotated with a
data-animejs-id attribute, by hand or by an upstream SVG annotation tool.
The primary mechanism for targeting individual elements annotated with a
data-animejs-id attribute, by hand or by an upstream SVG annotation tool.