| anime_target_id | R Documentation |
The primary mechanism for targeting individual elements annotated with a
data-animejs-id attribute, by hand or by an upstream SVG annotation tool.
anime_target_id(id)
id |
Character scalar. Value of the |
A CSS selector string of the form "[data-animejs-id='<id>']".
anime_target_id("c1")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.