This is the low-level constructor. Most users will not call this directly;
it is the final rendering step called by anime_render().
Arguments
- svg
Character. Raw SVG markup to embed in the widget. If
NULL, an empty string is used (the timeline will animate against existing DOM content – advanced use only).- timeline_config
List. A serialisable timeline specification produced by
anime_timeline()and its modifiers, then passed throughtimeline_to_json_config().- width
Fixed width for widget (in css units). The default is
NULL, which results in intelligent automatic sizing based on the widget's container.- height
Fixed height for widget (in css units). The default is
NULL, which results in intelligent automatic sizing based on the widget's container.- elementId
Use an explicit element ID for the widget (rather than an automatically generated one). Useful if you have other JavaScript that needs to explicitly discover and interact with a specific widget instance.