| animejs_widget | R Documentation |
This is the low-level constructor. Most users will not call this directly;
it is the final rendering step called by anime_render().
animejs_widget(svg, config, width = NULL, height = NULL, elementId = NULL)
svg |
Character. Raw SVG markup to embed in the widget. If |
config |
List. A serialisable animation specification produced by
|
width |
Fixed width for widget (in css units). The default is
|
height |
Fixed height for widget (in css units). The default is
|
elementId |
Use an explicit element ID for the widget (rather than an automatically generated one). Useful if you have other JavaScript that needs to explicitly discover and interact with a specific widget instance. |
An object of class c("animejs", "htmlwidget").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.